@@ -2,18 +2,18 @@ module Flipper
   module Adapters
     class Sync
       # Internal: Wraps a Synchronizer instance and only invokes it every
-      # N milliseconds.
+      # N seconds.
       class IntervalSynchronizer
-        # Private: Number of milliseconds between syncs (default: 10 seconds).
-        DEFAULT_INTERVAL_MS = 10_000
+        # Private: Number of seconds between syncs (default: 10).
+        DEFAULT_INTERVAL = 10
 
         # Private
-        def self.now_ms
-          Process.clock_gettime(Process::CLOCK_MONOTONIC, :millisecond)
+        def self.now
+          Process.clock_gettime(Process::CLOCK_MONOTONIC, :second)
         end
 
-        # Public: The number of milliseconds between invocations of the
-        # wrapped synchronizer.
+        # Public: The Float or Integer number of seconds between invocations of
+        # the wrapped synchronizer.
         attr_reader :interval
 
         # Public: Initializes a new interval synchronizer.
@@ -23,7 +23,7 @@ module Flipper
         #            the wrapped synchronizer.
         def initialize(synchronizer, interval: nil)
           @synchronizer = synchronizer
-          @interval = interval || DEFAULT_INTERVAL_MS
+          @interval = interval || DEFAULT_INTERVAL
           # TODO: add jitter to this so all processes booting at the same time
           # don't phone home at the same time.
           @last_sync_at = 0
@@ -32,7 +32,7 @@ module Flipper
         def call
           return unless time_to_sync?
 
-          @last_sync_at = now_ms
+          @last_sync_at = now
           @synchronizer.call
 
           nil
@@ -41,11 +41,12 @@ module Flipper
         private
 
         def time_to_sync?
-          (now_ms - @last_sync_at) >= @interval
+          seconds_since_last_sync = now - @last_sync_at
+          seconds_since_last_sync >= @interval
         end
 
-        def now_ms
-          self.class.now_ms
+        def now
+          self.class.now
         end
       end
     end
