@@ -1,7 +1,5 @@
 require 'rack'
 require 'flipper'
-require 'flipper/middleware/setup_env'
-require 'flipper/middleware/memoizer'
 require 'flipper/api/middleware'
 require 'flipper/api/json_params'
 
