@@ -6,7 +6,9 @@ module Flipper
     module V1
       module Actions
         class Feature < Api::Action
-          route %r{features/[^/]*/?\Z}
+          include FeatureNameFromRoute
+
+          route %r{\A/features/(?<feature_name>.*)/?\Z}
 
           def get
             return json_error_response(:feature_not_found) unless feature_exists?(feature_name)
@@ -21,10 +23,6 @@ module Flipper
 
           private
 
-          def feature_name
-            @feature_name ||= Rack::Utils.unescape(path_parts.last)
-          end
-
           def feature_exists?(feature_name)
             flipper.features.map(&:key).include?(feature_name)
           end
