@@ -3,7 +3,7 @@ require "flipper/adapters/sync/interval_synchronizer"
 
 RSpec.describe Flipper::Adapters::Sync::IntervalSynchronizer do
   let(:events) { [] }
-  let(:synchronizer) { -> { events << described_class.now_ms } }
+  let(:synchronizer) { -> { events << described_class.now } }
   let(:interval) { 10 }
 
   subject { described_class.new(synchronizer, interval: interval) }
@@ -14,20 +14,20 @@ RSpec.describe Flipper::Adapters::Sync::IntervalSynchronizer do
     expect(events.size).to be(1)
   end
 
-  it "only invokes wrapped synchronizer every interval milliseconds" do
-    now = described_class.now_ms
+  it "only invokes wrapped synchronizer every interval seconds" do
+    now = described_class.now
     subject.call
     events.clear
 
     # move time to one millisecond less than last sync + interval
     1.upto(interval) do |i|
-      allow(described_class).to receive(:now_ms).and_return(now + i - 1)
+      allow(described_class).to receive(:now).and_return(now + i - 1)
       subject.call
     end
     expect(events.size).to be(0)
 
-    # move time to last sync + interval
-    allow(described_class).to receive(:now_ms).and_return(now + interval)
+    # move time to last sync + interval in milliseconds
+    allow(described_class).to receive(:now).and_return(now + interval)
     subject.call
     expect(events.size).to be(1)
   end
