@@ -1,6 +1,5 @@
 require 'helper'
 require 'flipper/feature'
-require 'flipper/adapters/memory'
 require 'flipper/instrumenters/memory'
 
 RSpec.describe Flipper::Feature do
@@ -97,6 +96,17 @@ RSpec.describe Flipper::Feature do
     end
   end
 
+  describe '#exist?' do
+    it 'returns true if feature is added in adapter' do
+      subject.add
+      expect(subject.exist?).to be(true)
+    end
+
+    it 'returns false if feature is NOT added in adapter' do
+      expect(subject.exist?).to be(false)
+    end
+  end
+
   describe '#remove' do
     it 'removes feature from adapter' do
       adapter.add(subject)
@@ -232,6 +242,17 @@ RSpec.describe Flipper::Feature do
       expect(event.payload[:result]).not_to be_nil
     end
 
+    it 'is recorded for exist?' do
+      subject.exist?
+
+      event = instrumenter.events.last
+      expect(event).not_to be_nil
+      expect(event.name).to eq('feature_operation.flipper')
+      expect(event.payload[:feature_name]).to eq(:search)
+      expect(event.payload[:operation]).to eq(:exist?)
+      expect(event.payload[:result]).not_to be_nil
+    end
+
     it 'is recorded for remove' do
       subject.remove
 
@@ -509,12 +530,12 @@ RSpec.describe Flipper::Feature do
 
     context 'when one or more actors are enabled' do
       before do
-        subject.enable Flipper::Types::Actor.new(Flipper::Actor.new('User:5'))
-        subject.enable Flipper::Types::Actor.new(Flipper::Actor.new('User:22'))
+        subject.enable Flipper::Types::Actor.new(Flipper::Actor.new('User;5'))
+        subject.enable Flipper::Types::Actor.new(Flipper::Actor.new('User;22'))
       end
 
       it 'returns set of actor ids' do
-        expect(subject.actors_value).to eq(Set.new(['User:5', 'User:22']))
+        expect(subject.actors_value).to eq(Set.new(['User;5', 'User;22']))
       end
     end
   end
