@@ -3,13 +3,13 @@ require 'helper'
 RSpec.describe Flipper::UI::Actions::AddFeature do
   describe 'GET /features/new with feature_creation_enabled set to true' do
     before do
-      @original_feature_creation_enabled = Flipper::UI.feature_creation_enabled
-      Flipper::UI.feature_creation_enabled = true
+      @original_feature_creation_enabled = Flipper::UI.configuration.feature_creation_enabled
+      Flipper::UI.configuration.feature_creation_enabled = true
       get '/features/new'
     end
 
     after do
-      Flipper::UI.feature_creation_enabled = @original_feature_creation_enabled
+      Flipper::UI.configuration.feature_creation_enabled = @original_feature_creation_enabled
     end
 
     it 'responds with success' do
@@ -24,13 +24,13 @@ RSpec.describe Flipper::UI::Actions::AddFeature do
 
   describe 'GET /features/new with feature_creation_enabled set to false' do
     before do
-      @original_feature_creation_enabled = Flipper::UI.feature_creation_enabled
-      Flipper::UI.feature_creation_enabled = false
+      @original_feature_creation_enabled = Flipper::UI.configuration.feature_creation_enabled
+      Flipper::UI.configuration.feature_creation_enabled = false
       get '/features/new'
     end
 
     after do
-      Flipper::UI.feature_creation_enabled = @original_feature_creation_enabled
+      Flipper::UI.configuration.feature_creation_enabled = @original_feature_creation_enabled
     end
 
     it 'returns 403' do
